==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/thunks/changeMasterLayout.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/thunks/changeMasterLayout", ['module', 'exports', 'require', '../actions/changeMasterLayout', '../services/LayoutService'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = changeMasterLayout;

    var _changeMasterLayout = _interopRequireDefault(require("../actions/changeMasterLayout"));

    var _LayoutService = _interopRequireDefault(require("../services/LayoutService"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function changeMasterLayout(_ref) {
      var masterLayoutPlid = _ref.masterLayoutPlid;
      return function (dispatch) {
        return _LayoutService["default"].changeMasterLayout({
          masterLayoutPlid: masterLayoutPlid,
          onNetworkStatus: dispatch
        }).then(function () {
          var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
          dispatch((0, _changeMasterLayout["default"])({
            fragmentEntryLinks: data.fragmentEntryLinks,
            masterLayoutData: data.masterLayoutData,
            masterLayoutPlid: masterLayoutPlid
          }));
          return data;
        });
      };
    }
    //# sourceMappingURL=changeMasterLayout.js.map
  }
});
//# sourceMappingURL=changeMasterLayout.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/thunks/changeMasterLayout.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/thunks/changeMasterLayout", ['module', 'exports', 'require', '../actions/changeMasterLayout', '../services/LayoutService'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = changeMasterLayout;

    var _changeMasterLayout = _interopRequireDefault(require("../actions/changeMasterLayout"));

    var _LayoutService = _interopRequireDefault(require("../services/LayoutService"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    function changeMasterLayout(_ref) {
      var masterLayoutPlid = _ref.masterLayoutPlid;
      return function (dispatch) {
        return _LayoutService.default.changeMasterLayout({
          masterLayoutPlid: masterLayoutPlid,
          onNetworkStatus: dispatch
        }).then(function () {
          var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
          dispatch((0, _changeMasterLayout.default)({
            fragmentEntryLinks: data.fragmentEntryLinks,
            masterLayoutData: data.masterLayoutData,
            masterLayoutPlid: masterLayoutPlid
          }));
          return data;
        });
      };
    }
    //# sourceMappingURL=changeMasterLayout.js.map
  }
});
//# sourceMappingURL=changeMasterLayout.js.map
